@@ -74,8 +74,12 @@ enum
 static void  caja_history_sidebar_iface_init        (CajaSidebarIface         *iface);
 static void  sidebar_provider_iface_init                (CajaSidebarProviderIface *iface);
 static GType caja_history_sidebar_provider_get_type (void);
+#if GTK_CHECK_VERSION (3, 0, 0)
+static void  caja_history_sidebar_style_updated	        (GtkWidget *widget);
+#else
 static void  caja_history_sidebar_style_set	        (GtkWidget *widget,
         GtkStyle  *previous_style);
+#endif
 
 G_DEFINE_TYPE_WITH_CODE (CajaHistorySidebar, caja_history_sidebar, GTK_TYPE_SCROLLED_WINDOW,
                          G_IMPLEMENT_INTERFACE (CAJA_TYPE_SIDEBAR,
@@ -321,7 +325,11 @@ caja_history_sidebar_class_init (CajaHistorySidebarClass *class)
 {
     G_OBJECT_CLASS (class)->finalize = caja_history_sidebar_finalize;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+    GTK_WIDGET_CLASS (class)->style_updated = caja_history_sidebar_style_updated;
+#else
     GTK_WIDGET_CLASS (class)->style_set = caja_history_sidebar_style_set;
+#endif
 }
 
 static const char *
@@ -374,8 +382,12 @@ caja_history_sidebar_set_parent_window (CajaHistorySidebar *sidebar,
 }
 
 static void
+#if GTK_CHECK_VERSION (3, 0, 0)
+caja_history_sidebar_style_updated (GtkWidget *widget)
+#else
 caja_history_sidebar_style_set (GtkWidget *widget,
                                 GtkStyle  *previous_style)
+#endif
 {
     CajaHistorySidebar *sidebar;
 
