@@ -69,26 +69,10 @@
 #include <math.h>
 #include <sys/time.h>
 
-
-/* FIXME bugzilla.gnome.org 41243:
- * We should use inheritance instead of these special cases
- * for the desktop window.
- */
-#include "caja-desktop-window.h"
-
 #define MAX_TITLE_LENGTH 180
 
 #define MENU_PATH_BOOKMARKS_PLACEHOLDER			"/MenuBar/Other Menus/Bookmarks/Bookmarks Placeholder"
 
-enum
-{
-    ARG_0,
-    ARG_APP_ID,
-    ARG_APP
-};
-
-
-
 /* Forward and back buttons on the mouse */
 static gboolean mouse_extra_buttons = TRUE;
 static int mouse_forward_button = 9;
