@@ -38,7 +38,9 @@
 #include <gdk/gdkx.h>
 #include <glib/gi18n.h>
 #include <libcaja-private/caja-desktop-icon-file.h>
+#if !GTK_CHECK_VERSION(3, 21, 0)
 #include <libcaja-private/caja-directory-background.h>
+#endif
 #include <libcaja-private/caja-directory-notify.h>
 #include <libcaja-private/caja-file-changes-queue.h>
 #include <libcaja-private/caja-file-operations.h>
@@ -322,7 +324,37 @@ fm_desktop_icon_view_handle_middle_click (CajaIconContainer *icon_container,
         FMDesktopIconView *desktop_icon_view)
 {
     XButtonEvent x_event;
-#if GTK_CHECK_VERSION (3, 0, 0)
+#if GTK_CHECK_VERSION (3, 20, 0)
+    GdkDevice *keyboard = NULL, *pointer = NULL, *cur;
+    GdkSeat *seat;
+
+    seat = gdk_display_get_default_seat (gtk_widget_get_display (GTK_WIDGET (icon_container)));
+    pointer = gdk_seat_get_pointer (seat);
+    keyboard = gdk_seat_get_keyboard (seat);
+
+    {
+        if (pointer == NULL && (gdk_device_get_source (cur) == GDK_SOURCE_MOUSE)) {
+                pointer = cur;
+        }
+
+        if (keyboard == NULL && (gdk_device_get_source (cur) == GDK_SOURCE_KEYBOARD)) {
+                keyboard = cur;
+        }
+    }
+
+    /* During a mouse click we have the pointer and keyboard grab.
+     * We will send a fake event to the root window which will cause it
+     * to try to get the grab so we need to let go ourselves.
+     */
+
+    if (pointer != NULL) {
+            gdk_seat_ungrab (seat);
+    }
+
+    if (keyboard != NULL) {
+            gdk_seat_ungrab (seat);
+    }
+#elif GTK_CHECK_VERSION(3, 0, 0)
     GdkDevice *keyboard = NULL, *pointer = NULL, *cur;
     GdkDeviceManager *manager;
     GList *list, *l;
@@ -443,6 +475,7 @@ realized_callback (GtkWidget *widget, FMDesktopIconView *desktop_icon_view)
     gdk_window_add_filter (root_window,
                            desktop_icon_view_property_filter,
                            desktop_icon_view);
+
 }
 
 static CajaZoomLevel
